==> estateplat-common-1.2.4-20220622.062135-1050-sources.jar: cn/gtmap/estateplat/model/exchange/national/newStandard/QlfQlDyiqNew.java <==
package cn.gtmap.estateplat.model.exchange.national.newStandard;

import cn.gtmap.estateplat.model.exchange.national.AccessData;
import cn.gtmap.estateplat.utils.JaxbDateAdapter;
import cn.gtmap.estateplat.utils.JaxbDateTsAdapter;
import cn.gtmap.estateplat.utils.JaxbNotNullDateAdapter;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;
import cn.gtmap.sdk.mybatis.plugin.annotation.Crypt;

import javax.persistence.Table;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import java.io.Serializable;
import java.util.Date;

/**
 * 地役权
 * Created by xhc on 2015/11/20.
 */
@XmlRootElement(name = "QLF_QL_DYIQ")
@Table(name = "QLF_QL_DYIQ")
public class QlfQlDyiqNew implements Serializable, AccessData {
    final static String ysdm = "6002020900";//要素代码
    private String ywh;//业务号
    private String gydbdcdyh;//供地役不动产单元号
    private String gydqlr;//供役地权利人
    private String gydqlrzjzl;//供役地权利人证件种类
    @Crypt
    private String gydqlrzjh;//供役地权利人证件号
    private String xydbdcdyh;//需役地不动产单元号
    private String xydzl;//需役地坐落
    private String xydqlr;//需役地权利人
    private String xydqlrzjzl;//需役地权利人证件种类
    @Crypt
    private String xydqlrzjzh;//需役地权利人证件号
    private String djlx;//登记类型
    private String djyy;//登记原因
    private String dyqnr;//地役权内容
    private String bdcdjzmh;//不动产登记证明号
    private Date qlqssj;//权利起始时间
    private Date qljssj;//权利结束时间
    private String qxdm;//区县代码
    private String djjg;//登记机构
    private String dbr;//登簿人
    private Date djsj;//登记时间
    private String fj;//附记
    private String qszt;//权属状态
    /**  插入更新时间
     * @author <a href="mailto:zhangqiang@gtmap.cn">zhangqiang</a>
     * @description
     */
    private Date updatetime;
    /**  插入创建时间
     * @author <a href="mailto:zhangqiang@gtmap.cn">zhangqiang</a>
     * @description
     */
    private Date createtime;

    private String dzwbm;

    private String ssywh;
    private String qlqx;
    @XmlAttribute(name = "SSYWH")
    public String getSsywh() {
        return ssywh;
    }

    public void setSsywh(String ssywh) {
        this.ssywh = ssywh;
    }
    @XmlAttribute(name = "QLQX")
    public String getQlqx() {
        return qlqx;
    }

    public void setQlqx(String qlqx) {
        this.qlqx = qlqx;
    }

    @XmlTransient
    public Date getCreatetime() {
        return createtime;
    }

    public void setCreatetime(Date createtime) {
        this.createtime = createtime;
    }
    @XmlTransient
    public Date getUpdatetime() {
        return updatetime;
    }

    public void setUpdatetime(Date updatetime) {
        this.updatetime = updatetime;
    }

    @XmlAttribute(name = "YSDM")
    public String getYsdm() {
        return ysdm;
    }

    @XmlAttribute(name = "YWH")
    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    @XmlAttribute(name = "GYDBDCDYH")
    public String getGydbdcdyh() {
        return gydbdcdyh;
    }

    public void setGydbdcdyh(String gydbdcdyh) {
        this.gydbdcdyh = gydbdcdyh;
    }

    @XmlAttribute(name = "GYDQLR")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getGydqlr() {
        return gydqlr;
    }

    public void setGydqlr(String gydqlr) {
        this.gydqlr = gydqlr;
    }

    @XmlAttribute(name = "GYDQLRZJZL")
    public String getGydqlrzjzl() {
        return gydqlrzjzl;
    }

    public void setGydqlrzjzl(String gydqlrzjzl) {
        this.gydqlrzjzl = gydqlrzjzl;
    }

    @XmlAttribute(name = "GYDQLRZJH")
    public String getGydqlrzjh() {
        return gydqlrzjh;
    }

    public void setGydqlrzjh(String gydqlrzjh) {
        this.gydqlrzjh = gydqlrzjh;
    }

    @XmlAttribute(name = "XYDBDCDYH")
    public String getXydbdcdyh() {
        return xydbdcdyh;
    }

    public void setXydbdcdyh(String xydbdcdyh) {
        this.xydbdcdyh = xydbdcdyh;
    }

    @XmlAttribute(name = "XYDZL")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getXydzl() {
        return xydzl;
    }

    public void setXydzl(String xydzl) {
        this.xydzl = xydzl;
    }

    @XmlAttribute(name = "XYDQLR")
    public String getXydqlr() {
        return xydqlr;
    }

    public void setXydqlr(String xydqlr) {
        this.xydqlr = xydqlr;
    }

    @XmlAttribute(name = "XYDQLRZJZL")
    public String getXydqlrzjzl() {
        return xydqlrzjzl;
    }

    public void setXydqlrzjzl(String xydqlrzjzl) {
        this.xydqlrzjzl = xydqlrzjzl;
    }

    @XmlAttribute(name = "XYDQLRZJZH")
    public String getXydqlrzjzh() {
        return xydqlrzjzh;
    }

    public void setXydqlrzjzh(String xydqlrzjzh) {
        this.xydqlrzjzh = xydqlrzjzh;
    }

    @XmlAttribute(name = "DJLX")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDjlx() {
        return djlx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    @XmlAttribute(name = "DJYY")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDjyy() {
        return djyy;
    }

    public void setDjyy(String djyy) {
        this.djyy = djyy;
    }

    @XmlAttribute(name = "DYQNR")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDyqnr() {
        return dyqnr;
    }

    public void setDyqnr(String dyqnr) {
        this.dyqnr = dyqnr;
    }

    @XmlAttribute(name = "BDCDJZMH")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getBdcdjzmh() {
        return bdcdjzmh;
    }

    public void setBdcdjzmh(String bdcdjzmh) {
        this.bdcdjzmh = bdcdjzmh;
    }

    @XmlAttribute(name = "QLQSSJ")
    @XmlJavaTypeAdapter(JaxbNotNullDateAdapter.class)
    public Date getQlqssj() {
        return qlqssj;
    }

    public void setQlqssj(Date qlqssj) {
        this.qlqssj = qlqssj;
    }

    @XmlAttribute(name = "QLJSSJ")
    @XmlJavaTypeAdapter(JaxbNotNullDateAdapter.class)
    public Date getQljssj() {
        return qljssj;
    }

    public void setQljssj(Date qljssj) {
        this.qljssj = qljssj;
    }

    @XmlAttribute(name = "QXDM")
    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    @XmlAttribute(name = "DJJG")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDjjg() {
        return djjg;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }

    @XmlAttribute(name = "DBR")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    @XmlAttribute(name = "DJSJ")
    @XmlJavaTypeAdapter(JaxbNotNullDateAdapter.class)
    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    @XmlAttribute(name = "FJ")
    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    @XmlAttribute(name = "QSZT")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getQszt() {
        return qszt;
    }

    public void setQszt(String qszt) {
        this.qszt = qszt;
    }

    @XmlTransient
    public String getDzwbm() {
        return dzwbm;
    }

    public void setDzwbm(String dzwbm) {
        this.dzwbm = dzwbm;
    }
}

==> estateplat-common-1.2.4-20250321.012237-1299-sources.jar: cn/gtmap/estateplat/model/exchange/national/newStandard/QlfQlDyiqNew.java <==
package cn.gtmap.estateplat.model.exchange.national.newStandard;

import cn.gtmap.estateplat.model.exchange.national.AccessData;
import cn.gtmap.estateplat.utils.JaxbDateAdapter;
import cn.gtmap.estateplat.utils.JaxbDateTsAdapter;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;
import cn.gtmap.sdk.mybatis.plugin.annotation.Crypt;

import javax.persistence.Table;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import java.io.Serializable;
import java.util.Date;

/**
 * 地役权
 * Created by xhc on 2015/11/20.
 */
@XmlRootElement(name = "QLF_QL_DYIQ")
@Table(name = "QLF_QL_DYIQ")
public class QlfQlDyiqNew implements Serializable, AccessData {
    final static String ysdm = "6002020900";//要素代码
    private String ywh;//业务号
    private String gydbdcdyh;//供地役不动产单元号
    private String gydqlr;//供役地权利人
    private String gydqlrzjzl;//供役地权利人证件种类
    @Crypt
    private String gydqlrzjh;//供役地权利人证件号
    private String xydbdcdyh;//需役地不动产单元号
    private String xydzl;//需役地坐落
    private String xydqlr;//需役地权利人
    private String xydqlrzjzl;//需役地权利人证件种类
    @Crypt
    private String xydqlrzjzh;//需役地权利人证件号
    private String djlx;//登记类型
    private String djyy;//登记原因
    private String dyqnr;//地役权内容
    private String bdcdjzmh;//不动产登记证明号
    private Date qlqssj;//权利起始时间
    private Date qljssj;//权利结束时间
    private String qxdm;//区县代码
    private String djjg;//登记机构
    private String dbr;//登簿人
    private Date djsj;//登记时间
    private String fj;//附记
    private String qszt;//权属状态
    /**  插入更新时间
     * @author <a href="mailto:zhangqiang@gtmap.cn">zhangqiang</a>
     * @description
     */
    private Date updatetime;
    /**  插入创建时间
     * @author <a href="mailto:zhangqiang@gtmap.cn">zhangqiang</a>
     * @description
     */
    private Date createtime;

    private String dzwbm;

    private String ssywh;
    private String qlqx;
    @XmlAttribute(name = "SSYWH")
    public String getSsywh() {
        return ssywh;
    }

    public void setSsywh(String ssywh) {
        this.ssywh = ssywh;
    }
    @XmlAttribute(name = "QLQX")
    public String getQlqx() {
        return qlqx;
    }

    public void setQlqx(String qlqx) {
        this.qlqx = qlqx;
    }

    @XmlTransient
    public Date getCreatetime() {
        return createtime;
    }

    public void setCreatetime(Date createtime) {
        this.createtime = createtime;
    }
    @XmlTransient
    public Date getUpdatetime() {
        return updatetime;
    }

    public void setUpdatetime(Date updatetime) {
        this.updatetime = updatetime;
    }

    @XmlAttribute(name = "YSDM")
    public String getYsdm() {
        return ysdm;
    }

    @XmlAttribute(name = "YWH")
    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    @XmlAttribute(name = "GYDBDCDYH")
    public String getGydbdcdyh() {
        return gydbdcdyh;
    }

    public void setGydbdcdyh(String gydbdcdyh) {
        this.gydbdcdyh = gydbdcdyh;
    }

    @XmlAttribute(name = "GYDQLR")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getGydqlr() {
        return gydqlr;
    }

    public void setGydqlr(String gydqlr) {
        this.gydqlr = gydqlr;
    }

    @XmlAttribute(name = "GYDQLRZJZL")
    public String getGydqlrzjzl() {
        return gydqlrzjzl;
    }

    public void setGydqlrzjzl(String gydqlrzjzl) {
        this.gydqlrzjzl = gydqlrzjzl;
    }

    @XmlAttribute(name = "GYDQLRZJH")
    public String getGydqlrzjh() {
        return gydqlrzjh;
    }

    public void setGydqlrzjh(String gydqlrzjh) {
        this.gydqlrzjh = gydqlrzjh;
    }

    @XmlAttribute(name = "XYDBDCDYH")
    public String getXydbdcdyh() {
        return xydbdcdyh;
    }

    public void setXydbdcdyh(String xydbdcdyh) {
        this.xydbdcdyh = xydbdcdyh;
    }

    @XmlAttribute(name = "XYDZL")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getXydzl() {
        return xydzl;
    }

    public void setXydzl(String xydzl) {
        this.xydzl = xydzl;
    }

    @XmlAttribute(name = "XYDQLR")
    public String getXydqlr() {
        return xydqlr;
    }

    public void setXydqlr(String xydqlr) {
        this.xydqlr = xydqlr;
    }

    @XmlAttribute(name = "XYDQLRZJZL")
    public String getXydqlrzjzl() {
        return xydqlrzjzl;
    }

    public void setXydqlrzjzl(String xydqlrzjzl) {
        this.xydqlrzjzl = xydqlrzjzl;
    }

    @XmlAttribute(name = "XYDQLRZJZH")
    public String getXydqlrzjzh() {
        return xydqlrzjzh;
    }

    public void setXydqlrzjzh(String xydqlrzjzh) {
        this.xydqlrzjzh = xydqlrzjzh;
    }

    @XmlAttribute(name = "DJLX")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDjlx() {
        return djlx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    @XmlAttribute(name = "DJYY")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDjyy() {
        return djyy;
    }

    public void setDjyy(String djyy) {
        this.djyy = djyy;
    }

    @XmlAttribute(name = "DYQNR")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDyqnr() {
        return dyqnr;
    }

    public void setDyqnr(String dyqnr) {
        this.dyqnr = dyqnr;
    }

    @XmlAttribute(name = "BDCDJZMH")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getBdcdjzmh() {
        return bdcdjzmh;
    }

    public void setBdcdjzmh(String bdcdjzmh) {
        this.bdcdjzmh = bdcdjzmh;
    }

    @XmlAttribute(name = "QLQSSJ")
    @XmlJavaTypeAdapter(JaxbDateAdapter.class)
    public Date getQlqssj() {
        return qlqssj;
    }

    public void setQlqssj(Date qlqssj) {
        this.qlqssj = qlqssj;
    }

    @XmlAttribute(name = "QLJSSJ")
    @XmlJavaTypeAdapter(JaxbDateAdapter.class)
    public Date getQljssj() {
        return qljssj;
    }

    public void setQljssj(Date qljssj) {
        this.qljssj = qljssj;
    }

    @XmlAttribute(name = "QXDM")
    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    @XmlAttribute(name = "DJJG")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDjjg() {
        return djjg;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }

    @XmlAttribute(name = "DBR")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    @XmlAttribute(name = "DJSJ")
    @XmlJavaTypeAdapter(JaxbDateAdapter.class)
    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    @XmlAttribute(name = "FJ")
    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    @XmlAttribute(name = "QSZT")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getQszt() {
        return qszt;
    }

    public void setQszt(String qszt) {
        this.qszt = qszt;
    }

    @XmlTransient
    public String getDzwbm() {
        return dzwbm;
    }

    public void setDzwbm(String dzwbm) {
        this.dzwbm = dzwbm;
    }
}
